linux-kernel.vger.kernel.org archive mirror
 help / color / mirror / Atom feed
* kernel BUG at arch/x86/kernel/apic/apic.c with Dell server with x2APIC enabled and unset X2APIC
@ 2020-02-21 14:37 Paul Menzel
  2020-02-21 15:57 ` Borislav Petkov
                   ` (2 more replies)
  0 siblings, 3 replies; 7+ messages in thread
From: Paul Menzel @ 2020-02-21 14:37 UTC (permalink / raw)
  To: Thomas Gleixner, Ingo Molnar, Borislav Petkov; +Cc: x86, LKML, it+linux-x86

[-- Attachment #1: Type: text/plain, Size: 4186 bytes --]

Dear Linux folks,


On the Dell PowerEdge T640/04WYPY, BIOS 2.4.8 11/27/2019, Linux 5.4.14 (and 4.19.57) with
unset `IRQ_REMAP` and `X86_X2APIC` crashes on start-up, when x2APIC is enabled in the
firmware.

    [    3.862327] ACPI: Core revision 20190816
    [    3.869551] clocksource: hpet: mask: 0xffffffff max_cycles: 0xffffffff, max_idle_ns: 79635855245 ns
    [    3.878797] APIC: Switch to symmetric I/O mode setup
    [    3.883893] Switched APIC routing to physical flat.
    [    3.888904] ------------[ cut here ]------------
    [    3.893641] kernel BUG at arch/x86/kernel/apic/apic.c:1616!
    [    3.899347] invalid opcode: 0000 [#1] SMP NOPTI
    [    3.903990] CPU: 0 PID: 0 Comm: swapper/0 Not tainted 5.4.14.mx64.317 #1
    [    3.910803] Hardware name: Dell Inc. PowerEdge T640/04WYPY, BIOS 2.4.8 11/27/2019
    [    3.918448] RIP: 0010:setup_local_APIC+0x32e/0x390
    [    3.923356] Code: 68 70 2e 01 be 00 07 01 00 bf 50 03 00 00 48 8b 40 10 e8 15 9e db 00 eb a9 be 00 04 01 00 bf 60 03 00 00 e8 04 9e db 00 eb bb <0f> 0b e8 5b 3a 00 00
    [    3.942300] RSP: 0000:ffffffff82403e88 EFLAGS: 00010246
    [    3.947641] RAX: 0000000000000000 RBX: 00000000000000ff RCX: ffffffff82454128
    [    3.955787] RDX: 0000000000000000 RSI: 00000000fffffeff RDI: 0000000000000020
    [    3.963031] RBP: ffffffffffffffff R08: 00000000000001c4 R09: 0734073407370739
    [    3.970277] R10: ffffffff82573000 R11: 0720072007730765 R12: ffffffff82a4a920
    [    3.977522] R13: 0000000000000000 R14: ffff88c07fff0e80 R15: 0000000000000000
    [    3.984766] FS:  0000000000000000(0000) GS:ffff889fffc00000(0000) knlGS:0000000000000000
    [    3.993014] CS:  0010 DS: 0000 ES: 0000 CR0: 0000000080050033
    [    3.998876] CR2: ffff88c07ffff000 CR3: 000000000240a001 CR4: 00000000000606b0
    [    4.006121] DR0: 0000000000000000 DR1: 0000000000000000 DR2: 0000000000000000
    [    4.013365] DR3: 0000000000000000 DR6: 00000000fffe0ff0 DR7: 0000000000000400
    [    4.020611] Call Trace:
    [    4.023184]  apic_intr_mode_init+0x1d2/0x1ec
    [    4.027573]  x86_late_time_init+0x17/0x1c
    [    4.031706]  start_kernel+0x41f/0x4d3
    [    4.035491]  secondary_startup_64+0xa4/0xb0
    [    4.039797] Modules linked in:
    [    4.042997] ---[ end trace c3629ce2e87a638c ]---
    [    4.047746] RIP: 0010:setup_local_APIC+0x32e/0x390
    [    4.052663] Code: 68 70 2e 01 be 00 07 01 00 bf 50 03 00 00 48 8b 40 10 e8 15 9e db 00 eb a9 be 00 04 01 00 bf 60 03 00 00 e8 04 9e db 00 eb bb <0f> 0b e8 5b 3a 00 00
    [    4.071617] RSP: 0000:ffffffff82403e88 EFLAGS: 00010246
    [    4.076966] RAX: 0000000000000000 RBX: 00000000000000ff RCX: ffffffff82454128
    [    4.084219] RDX: 0000000000000000 RSI: 00000000fffffeff RDI: 0000000000000020
    [    4.091475] RBP: ffffffffffffffff R08: 00000000000001c4 R09: 0734073407370739
    [    4.098738] R10: ffffffff82573000 R11: 0720072007730765 R12: ffffffff82a4a920
    [    4.106000] R13: 0000000000000000 R14: ffff88c07fff0e80 R15: 0000000000000000
    [    4.113252] FS:  0000000000000000(0000) GS:ffff889fffc00000(0000) knlGS:0000000000000000
    [    4.121509] CS:  0010 DS: 0000 ES: 0000 CR0: 0000000080050033
    [    4.127380] CR2: ffff88c07ffff000 CR3: 000000000240a001 CR4: 00000000000606b0
    [    4.134632] DR0: 0000000000000000 DR1: 0000000000000000 DR2: 0000000000000000
    [    4.141887] DR3: 0000000000000000 DR6: 00000000fffe0ff0 DR7: 0000000000000400
    [    4.149142] Kernel panic - not syncing: Attempted to kill the idle task!
    [    4.155968] ---[ end Kernel panic - not syncing: Attempted to kill the idle task! ]---

This is the code below.

        /*
         * Double-check whether this APIC is really registered.
         * This is meaningless in clustered apic mode, so we skip it.
         */
        BUG_ON(!apic->apic_id_registered());

Should this be made a similar error as in `validate_x2apic`?

	panic("BIOS has enabled x2apic but kernel doesn't support x2apic, please disable x2apic in BIOS.\n");

`noapic` and `acpi=off` separately did not work, but `noapic acpi=off` hit the other
panic.


Kind regards,

Paul


[-- Attachment #2: S/MIME Cryptographic Signature --]
[-- Type: application/pkcs7-signature, Size: 5174 bytes --]

^ permalink raw reply	[flat|nested] 7+ messages in thread

* Re: kernel BUG at arch/x86/kernel/apic/apic.c with Dell server with x2APIC enabled and unset X2APIC
  2020-02-21 14:37 kernel BUG at arch/x86/kernel/apic/apic.c with Dell server with x2APIC enabled and unset X2APIC Paul Menzel
@ 2020-02-21 15:57 ` Borislav Petkov
  2020-02-21 16:15   ` Paul Menzel
  2020-02-21 16:27 ` Thomas Gleixner
  2022-12-02 13:35 ` [tip: x86/apic] x86/apic: Handle no CONFIG_X86_X2APIC on systems with x2APIC enabled by BIOS tip-bot2 for Mateusz Jończyk
  2 siblings, 1 reply; 7+ messages in thread
From: Borislav Petkov @ 2020-02-21 15:57 UTC (permalink / raw)
  To: Paul Menzel; +Cc: Thomas Gleixner, Ingo Molnar, x86, LKML, it+linux-x86

On Fri, Feb 21, 2020 at 03:37:23PM +0100, Paul Menzel wrote:
> Dear Linux folks,
> 
> 
> On the Dell PowerEdge T640/04WYPY, BIOS 2.4.8 11/27/2019, Linux 5.4.14 (and 4.19.57) with
> unset `IRQ_REMAP` and `X86_X2APIC` crashes on start-up, when x2APIC is enabled in the
> firmware.

Does it happen with latest 5.5-stable too? I see 5.5.5 is the last one...

-- 
Regards/Gruss,
    Boris.

https://people.kernel.org/tglx/notes-about-netiquette

^ permalink raw reply	[flat|nested] 7+ messages in thread

* Re: kernel BUG at arch/x86/kernel/apic/apic.c with Dell server with x2APIC enabled and unset X2APIC
  2020-02-21 15:57 ` Borislav Petkov
@ 2020-02-21 16:15   ` Paul Menzel
  2020-02-21 16:27     ` Paul Menzel
  0 siblings, 1 reply; 7+ messages in thread
From: Paul Menzel @ 2020-02-21 16:15 UTC (permalink / raw)
  To: Borislav Petkov; +Cc: Thomas Gleixner, Ingo Molnar, x86, LKML, it+linux-x86

[-- Attachment #1: Type: text/plain, Size: 478 bytes --]

Dear Borislav,


On 2020-02-21 16:57, Borislav Petkov wrote:
> On Fri, Feb 21, 2020 at 03:37:23PM +0100, Paul Menzel wrote:

>> On the Dell PowerEdge T640/04WYPY, BIOS 2.4.8 11/27/2019, Linux 5.4.14 (and 4.19.57) with
>> unset `IRQ_REMAP` and `X86_X2APIC` crashes on start-up, when x2APIC is enabled in the
>> firmware.
> 
> Does it happen with latest 5.5-stable too? I see 5.5.5 is the last one...

It also happens with Linux 5.6-rc2.


Kind regards,

Paul


[-- Attachment #2: S/MIME Cryptographic Signature --]
[-- Type: application/pkcs7-signature, Size: 5174 bytes --]

^ permalink raw reply	[flat|nested] 7+ messages in thread

* Re: kernel BUG at arch/x86/kernel/apic/apic.c with Dell server with x2APIC enabled and unset X2APIC
  2020-02-21 14:37 kernel BUG at arch/x86/kernel/apic/apic.c with Dell server with x2APIC enabled and unset X2APIC Paul Menzel
  2020-02-21 15:57 ` Borislav Petkov
@ 2020-02-21 16:27 ` Thomas Gleixner
  2020-02-24 12:59   ` Paul Menzel
  2022-12-02 13:35 ` [tip: x86/apic] x86/apic: Handle no CONFIG_X86_X2APIC on systems with x2APIC enabled by BIOS tip-bot2 for Mateusz Jończyk
  2 siblings, 1 reply; 7+ messages in thread
From: Thomas Gleixner @ 2020-02-21 16:27 UTC (permalink / raw)
  To: Paul Menzel, Ingo Molnar, Borislav Petkov; +Cc: x86, LKML, it+linux-x86

Paul,

Paul Menzel <pmenzel@molgen.mpg.de> writes:
>
> On the Dell PowerEdge T640/04WYPY, BIOS 2.4.8 11/27/2019, Linux 5.4.14 (and 4.19.57) with
> unset `IRQ_REMAP` and `X86_X2APIC` crashes on start-up, when x2APIC is enabled in the
> firmware.

>     [    3.883893] Switched APIC routing to physical flat.
>     [    3.888904] ------------[ cut here ]------------
>     [    3.893641] kernel BUG at arch/x86/kernel/apic/apic.c:1616!

So the APIC is not registered.
>
> `noapic` and `acpi=off` separately did not work, but `noapic acpi=off` hit the other
> panic.

I have no idea what you are talking about.

Which command line options are set to reproduce the above?

Also please test the latest stable kernels not some random ones.

Thanks,

        tglx

^ permalink raw reply	[flat|nested] 7+ messages in thread

* Re: kernel BUG at arch/x86/kernel/apic/apic.c with Dell server with x2APIC enabled and unset X2APIC
  2020-02-21 16:15   ` Paul Menzel
@ 2020-02-21 16:27     ` Paul Menzel
  0 siblings, 0 replies; 7+ messages in thread
From: Paul Menzel @ 2020-02-21 16:27 UTC (permalink / raw)
  To: Borislav Petkov; +Cc: Thomas Gleixner, Ingo Molnar, x86, LKML, it+linux-x86


[-- Attachment #1.1: Type: text/plain, Size: 6386 bytes --]

Dear Borislav,


On 2020-02-21 17:15, Paul Menzel wrote:

> On 2020-02-21 16:57, Borislav Petkov wrote:
>> On Fri, Feb 21, 2020 at 03:37:23PM +0100, Paul Menzel wrote:
> 
>>> On the Dell PowerEdge T640/04WYPY, BIOS 2.4.8 11/27/2019, Linux 5.4.14 (and 4.19.57) with
>>> unset `IRQ_REMAP` and `X86_X2APIC` crashes on start-up, when x2APIC is enabled in the
>>> firmware.
>>
>> Does it happen with latest 5.5-stable too? I see 5.5.5 is the last one...
> 
> It also happens with Linux 5.6-rc2.

```
[…]
[    1.026337] IOAPIC[8]: apic_id 18, version 32, address 0xfec38000, GSI 96-103
[    1.026340] ACPI: INT_SRC_OVR (bus 0 bus_irq 0 global_irq 2 dfl dfl)
[    1.026342] ACPI: INT_SRC_OVR (bus 0 bus_irq 9 global_irq 9 high level)
[    1.026348] Using ACPI (MADT) for SMP configuration information
[    1.026350] ACPI: HPET id: 0x8086a701 base: 0xfed00000
[    1.026353] smpboot: Allowing 40 CPUs, 0 hotplug CPUs
[    1.026370] [mem 0x90000000-0xfdffffff] available for PCI devices
[    1.026374] clocksource: refined-jiffies: mask: 0xffffffff max_cycles: 0xffffffff, max_idle_ns: 1910969940391419 ns
[    1.031515] setup_percpu: NR_CPUS:256 nr_cpumask_bits:256 nr_cpu_ids:40 nr_node_ids:2
[    1.034956] percpu: Embedded 54 pages/cpu s180504 r8192 d32488 u262144
[    1.034999] Built 2 zonelists, mobility grouping on.  Total pages: 65922237
[    1.035000] Policy zone: Normal
[    1.035001] Kernel command line: BOOT_IMAGE=/boot/bzImage-5.6.0-rc2.mx64.322 root=LABEL=root ro crashkernel=256M console=ttyS1,115200n8 console=tty0 init=/bin/systemd audit=0 random.trust_cpu=on
[    1.035112] audit: disabled (until reboot)
[    1.035136] printk: log_buf_len individual max cpu contribution: 4096 bytes
[    1.035137] printk: log_buf_len total cpu_extra contributions: 159744 bytes
[    1.035138] printk: log_buf_len min size: 131072 bytes
[    1.035302] printk: log_buf_len: 524288 bytes
[    1.035303] printk: early log buf free: 106124(80%)
[    1.035646] mem auto-init: stack:off, heap alloc:off, heap free:off
[    1.632683] Memory: 263209212K/267879304K available (14340K kernel code, 1625K rwdata, 3656K rodata, 1540K init, 972K bss, 4670092K reserved, 0K cma-reserved)
[    1.633469] ftrace: allocating 41240 entries in 162 pages
[    1.648215] ftrace: allocated 162 pages with 3 groups
[    1.648467] rcu: Hierarchical RCU implementation.
[    1.648467] rcu:     RCU event tracing is enabled.
[    1.648468] rcu:     RCU restricting CPUs from NR_CPUS=256 to nr_cpu_ids=40.
[    1.648470] rcu: RCU calculated value of scheduler-enlistment delay is 100 jiffies.
[    1.648470] rcu: Adjusting geometry for rcu_fanout_leaf=16, nr_cpu_ids=40
[    1.651303] NR_IRQS: 16640, nr_irqs: 2104, preallocated irqs: 16
[    1.651609] random: crng done (trusting CPU's manufacturer)
[    1.652452] Console: colour dummy device 80x25
[    1.652883] printk: console [tty0] enabled
[    3.669892] printk: console [ttyS1] enabled
[    3.674156] ACPI: Core revision 20200110
[    3.681230] clocksource: hpet: mask: 0xffffffff max_cycles: 0xffffffff, max_idle_ns: 79635855245 ns
[    3.690285] APIC: Switch to symmetric I/O mode setup
[    3.695246] Switched APIC routing to physical flat.
[    3.700124] ------------[ cut here ]------------
[    3.704726] kernel BUG at arch/x86/kernel/apic/apic.c:1629!
[    3.710300] invalid opcode: 0000 [#1] SMP NOPTI
[    3.714815] CPU: 0 PID: 0 Comm: swapper/0 Not tainted 5.6.0-rc2.mx64.322 #1
[    3.721756] Hardware name: Dell Inc. PowerEdge T640/04WYPY, BIOS 2.4.8 11/27/2019
[    3.729222] RIP: 0010:setup_local_APIC+0x32e/0x390
[    3.734001] Code: 78 57 2e 01 be 00 07 01 00 bf 50 03 00 00 48 8b 40 10 e8 35 85 db 00 eb a9 be 00 04 01 00 bf 60 03 00 00 e8 24 85 db 00 eb bb <0f> 0b e8 5b 3a 00 00 e9 11 ff ff ff be 00 04 00 00 bf 60 03 00 00
[    3.752700] RSP: 0000:ffffffff82403e90 EFLAGS: 00010246
[    3.757914] RAX: 0000000000000000 RBX: 00000000000000a2 RCX: ffffffff82456088
[    3.765029] RDX: 0000000000000000 RSI: 00000000fffffeff RDI: 0000000000000020
[    3.772144] RBP: 0000000000000000 R08: 00000000000001cc R09: 0720072007200720
[    3.779260] R10: ffffffff8258d940 R11: 0720072007200720 R12: ffff88c07ffeee80
[    3.786374] R13: 0000000000000000 R14: 00000000000000a2 R15: 000000004647bcbc
[    3.793492] FS:  0000000000000000(0000) GS:ffff889fffe00000(0000) knlGS:0000000000000000
[    3.801557] CS:  0010 DS: 0000 ES: 0000 CR0: 0000000080050033
[    3.807288] CR2: ffff88c07ffff000 CR3: 000000000240a001 CR4: 00000000000606b0
[    3.814405] DR0: 0000000000000000 DR1: 0000000000000000 DR2: 0000000000000000
[    3.821520] DR3: 0000000000000000 DR6: 00000000fffe0ff0 DR7: 0000000000000400
[    3.828633] Call Trace:
[    3.831077]  apic_intr_mode_init+0xd6/0xef
[    3.835165]  x86_late_time_init+0x20/0x25
[    3.839167]  start_kernel+0x66b/0x71f
[    3.842825]  secondary_startup_64+0xa4/0xb0
[    3.846998] Modules linked in:
[    3.850077] ---[ end trace a223188007b81154 ]---
[    3.854697] RIP: 0010:setup_local_APIC+0x32e/0x390
[    3.859486] Code: 78 57 2e 01 be 00 07 01 00 bf 50 03 00 00 48 8b 40 10 e8 35 85 db 00 eb a9 be 00 04 01 00 bf 60 03 00 00 e8 24 85 db 00 eb bb <0f> 0b e8 5b 3a 00 00 e9 11 ff ff ff be 00 04 00 00 bf 60 03 00 00
[    3.878196] RSP: 0000:ffffffff82403e90 EFLAGS: 00010246
[    3.883418] RAX: 0000000000000000 RBX: 00000000000000a2 RCX: ffffffff82456088
[    3.890540] RDX: 0000000000000000 RSI: 00000000fffffeff RDI: 0000000000000020
[    3.897666] RBP: 0000000000000000 R08: 00000000000001cc R09: 0720072007200720
[    3.904790] R10: ffffffff8258d940 R11: 0720072007200720 R12: ffff88c07ffeee80
[    3.911913] R13: 0000000000000000 R14: 00000000000000a2 R15: 000000004647bcbc
[    3.919037] FS:  0000000000000000(0000) GS:ffff889fffe00000(0000) knlGS:0000000000000000
[    3.927113] CS:  0010 DS: 0000 ES: 0000 CR0: 0000000080050033
[    3.932854] CR2: ffff88c07ffff000 CR3: 000000000240a001 CR4: 00000000000606b0
[    3.939977] DR0: 0000000000000000 DR1: 0000000000000000 DR2: 0000000000000000
[    3.947100] DR3: 0000000000000000 DR6: 00000000fffe0ff0 DR7: 0000000000000400
[    3.954225] Kernel panic - not syncing: Attempted to kill the idle task!
[    3.960923] ---[ end Kernel panic - not syncing: Attempted to kill the idle tas
```

Please find all messages attached.


Kind regards,

Paul

[-- Attachment #1.2: linux-5.6-rc2-messages.txt --]
[-- Type: text/plain, Size: 26175 bytes --]

[    0.000000] Linux version 5.6.0-rc2.mx64.322 (root@thebiglebowserver.molgen.mpg.de) (gcc version 7.5.0 (GCC)) #1 SMP Mon Feb 17 13:39:28 CET 2020
[    0.000000] Command line: BOOT_IMAGE=/boot/bzImage-5.6.0-rc2.mx64.322 root=LABEL=root ro crashkernel=256M console=ttyS1,115200n8 console=tty0 init=/bin/systemd audit=0 random.trust_cpu=on
[    0.000000] x86/fpu: Supporting XSAVE feature 0x001: 'x87 floating point registers'
[    0.000000] x86/fpu: Supporting XSAVE feature 0x002: 'SSE registers'
[    0.000000] x86/fpu: Supporting XSAVE feature 0x004: 'AVX registers'
[    0.000000] x86/fpu: Supporting XSAVE feature 0x008: 'MPX bounds registers'
[    0.000000] x86/fpu: Supporting XSAVE feature 0x010: 'MPX CSR'
[    0.000000] x86/fpu: Supporting XSAVE feature 0x020: 'AVX-512 opmask'
[    0.000000] x86/fpu: Supporting XSAVE feature 0x040: 'AVX-512 Hi256'
[    0.000000] x86/fpu: Supporting XSAVE feature 0x080: 'AVX-512 ZMM_Hi256'
[    0.000000] x86/fpu: Supporting XSAVE feature 0x200: 'Protection Keys User registers'
[    0.000000] x86/fpu: xstate_offset[2]:  576, xstate_sizes[2]:  256
[    0.000000] x86/fpu: xstate_offset[3]:  832, xstate_sizes[3]:   64
[    0.000000] x86/fpu: xstate_offset[4]:  896, xstate_sizes[4]:   64
[    0.000000] x86/fpu: xstate_offset[5]:  960, xstate_sizes[5]:   64
[    0.000000] x86/fpu: xstate_offset[6]: 1024, xstate_sizes[6]:  512
[    0.000000] x86/fpu: xstate_offset[7]: 1536, xstate_sizes[7]: 1024
[    0.000000] x86/fpu: xstate_offset[9]: 2560, xstate_sizes[9]:    8
[    0.000000] x86/fpu: Enabled xstate features 0x2ff, context size is 2568 bytes, using 'compacted' format.
[    0.000000] BIOS-provided physical RAM map:
[    0.000000] BIOS-e820: [mem 0x0000000000000000-0x000000000009ffff] usable
[    0.000000] BIOS-e820: [mem 0x00000000000a0000-0x00000000000fffff] reserved
[    0.000000] BIOS-e820: [mem 0x0000000000100000-0x00000000474a3fff] usable
[    0.000000] BIOS-e820: [mem 0x00000000474a4000-0x000000004758efff] type 20
[    0.000000] BIOS-e820: [mem 0x000000004758f000-0x000000004761bfff] usable
[    0.000000] BIOS-e820: [mem 0x000000004761c000-0x00000000476edfff] type 20
[    0.000000] BIOS-e820: [mem 0x00000000476ee000-0x000000005e2fefff] usable
[    0.000000] BIOS-e820: [mem 0x000000005e2ff000-0x000000005e3fefff] reserved
[    0.000000] BIOS-e820: [mem 0x000000005e3ff000-0x000000005e5fefff] type 20
[    0.000000] BIOS-e820: [mem 0x000000005e5ff000-0x000000006d7fefff] reserved
[    0.000000] BIOS-e820: [mem 0x000000006d7ff000-0x000000006f7fefff] ACPI NVS
[    0.000000] BIOS-e820: [mem 0x000000006f7ff000-0x000000006fffefff] ACPI data
[    0.000000] BIOS-e820: [mem 0x000000006ffff000-0x000000006fffffff] usable
[    0.000000] BIOS-e820: [mem 0x0000000070000000-0x000000008fffffff] reserved
[    0.000000] BIOS-e820: [mem 0x00000000fe000000-0x00000000fe010fff] reserved
[    0.000000] BIOS-e820: [mem 0x0000000100000000-0x000000407fffffff] usable
[    0.000000] NX (Execute Disable) protection: active
[    0.000000] efi: EFI v2.70 by Dell Inc.
[    0.000000] efi:  ACPI=0x6fffe000  ACPI 2.0=0x6fffe014  SMBIOS=0x5fa33000  SMBIOS 3.0=0x5fa31000  MEMATTR=0x5b303020
[    0.000000] SMBIOS 3.2.0 present.
[    0.000000] DMI: Dell Inc. PowerEdge T640/04WYPY, BIOS 2.4.8 11/27/2019
[    0.000000] tsc: Detected 2200.000 MHz processor
[    0.000012] last_pfn = 0x4080000 max_arch_pfn = 0x400000000
[    0.000372] x86/PAT: Configuration [0-7]: WB  WC  UC- UC  WB  WP  UC- WT
[    0.000791] last_pfn = 0x70000 max_arch_pfn = 0x400000000
[    0.008196] kexec: Reserving the low 1M of memory for crashkernel
[    0.008199] Using GB pages for direct mapping
[    0.008661] Secure boot could not be determined
[    0.008662] RAMDISK: [mem 0x375e7000-0x37aeafff]
[    0.008666] ACPI: Early table checksum verification disabled
[    0.008668] ACPI: RSDP 0x000000006FFFE014 000024 (v02 DELL  )
[    0.008671] ACPI: XSDT 0x000000006FC15188 0000EC (v01 DELL   PE_SC3   00000000      01000013)
[    0.008676] ACPI: FACP 0x000000006FFF9000 000114 (v06 DELL   PE_SC3   00000000 DELL 00000001)
[    0.008680] ACPI: DSDT 0x000000006FD01000 2E8F17 (v02 DELL   PE_SC3   00000003 DELL 00000001)
[    0.008683] ACPI: FACS 0x000000006F26E000 000040
[    0.008685] ACPI: SSDT 0x000000006FFFC000 00046C (v02 INTEL  ADDRXLAT 00000001 INTL 20180508)
[    0.008687] ACPI: WD__ 0x000000006FFFB000 000134 (v01 DELL   PE_SC3   00000001 DELL 00000001)
[    0.008690] ACPI: SLIC 0x000000006FFFA000 000024 (v01 DELL   PE_SC3   00000001 DELL 00000001)
[    0.008692] ACPI: HPET 0x000000006FFF8000 000038 (v01 DELL   PE_SC3   00000001 DELL 00000001)
[    0.008694] ACPI: APIC 0x000000006FFF6000 0016DE (v04 DELL   PE_SC3   00000000 DELL 00000001)
[    0.008697] ACPI: MCFG 0x000000006FFF5000 00003C (v01 DELL   PE_SC3   00000001 DELL 00000001)
[    0.008699] ACPI: MIGT 0x000000006FFF4000 000040 (v01 DELL   PE_SC3   00000000 DELL 00000001)
[    0.008701] ACPI: MSCT 0x000000006FFF3000 000090 (v01 DELL   PE_SC3   00000001 DELL 00000001)
[    0.008703] ACPI: PCAT 0x000000006FFF2000 000088 (v02 DELL   PE_SC3   00000002 DELL 00000001)
[    0.008706] ACPI: PCCT 0x000000006FFF1000 00006E (v01 DELL   PE_SC3   00000002 DELL 00000001)
[    0.008708] ACPI: RASF 0x000000006FFF0000 000030 (v01 DELL   PE_SC3   00000001 DELL 00000001)
[    0.008710] ACPI: SLIT 0x000000006FFEF000 00042C (v01 DELL   PE_SC3   00000001 DELL 00000001)
[    0.008712] ACPI: SRAT 0x000000006FFEC000 002D30 (v03 DELL   PE_SC3   00000002 DELL 00000001)
[    0.008715] ACPI: SVOS 0x000000006FFEB000 000032 (v01 DELL   PE_SC3   00000000 DELL 00000001)
[    0.008717] ACPI: WSMT 0x000000006FFEA000 000028 (v01 DELL   PE_SC3   00000000 DELL 00000001)
[    0.008719] ACPI: OEM4 0x000000006FC53000 0AD1C1 (v02 INTEL  CPU  CST 00003000 INTL 20180508)
[    0.008722] ACPI: SSDT 0x000000006FC1B000 037465 (v02 INTEL  SSDT  PM 00004000 INTL 20180508)
[    0.008724] ACPI: SSDT 0x000000006FC01000 000A1F (v02 DELL   PE_SC3   00000000 DELL 00000001)
[    0.008726] ACPI: SSDT 0x000000006FC17000 00357F (v02 INTEL  SpsNm    00000002 INTL 20180508)
[    0.008729] ACPI: DMAR 0x000000006FC16000 0001E0 (v01 DELL   PE_SC3   00000001 DELL 00000001)
[    0.008731] ACPI: HEST 0x000000006FFFD000 00017C (v01 DELL   PE_SC3   00000002 DELL 00000001)
[    0.008733] ACPI: BERT 0x000000006FC14000 000030 (v01 DELL   PE_SC3   00000002 DELL 00000001)
[    0.008735] ACPI: ERST 0x000000006FC13000 000230 (v01 DELL   PE_SC3   00000002 DELL 00000001)
[    0.008738] ACPI: EINJ 0x000000006FC12000 000150 (v01 DELL   PE_SC3   00000002 DELL 00000001)
[    0.008820] SRAT: PXM 0 -> APIC 0x0000 -> Node 0
[    0.008821] SRAT: PXM 1 -> APIC 0x0020 -> Node 1
[    0.008822] SRAT: PXM 0 -> APIC 0x0008 -> Node 0
[    0.008823] SRAT: PXM 1 -> APIC 0x0028 -> Node 1
[    0.008823] SRAT: PXM 0 -> APIC 0x0002 -> Node 0
[    0.008824] SRAT: PXM 1 -> APIC 0x0022 -> Node 1
[    0.008825] SRAT: PXM 0 -> APIC 0x0006 -> Node 0
[    0.008825] SRAT: PXM 1 -> APIC 0x0026 -> Node 1
[    0.008826] SRAT: PXM 0 -> APIC 0x0004 -> Node 0
[    0.008827] SRAT: PXM 1 -> APIC 0x0024 -> Node 1
[    0.008827] SRAT: PXM 0 -> APIC 0x0018 -> Node 0
[    0.008828] SRAT: PXM 1 -> APIC 0x0038 -> Node 1
[    0.008829] SRAT: PXM 0 -> APIC 0x0010 -> Node 0
[    0.008829] SRAT: PXM 1 -> APIC 0x0030 -> Node 1
[    0.008830] SRAT: PXM 0 -> APIC 0x0016 -> Node 0
[    0.008831] SRAT: PXM 1 -> APIC 0x0036 -> Node 1
[    0.008831] SRAT: PXM 0 -> APIC 0x0012 -> Node 0
[    0.008832] SRAT: PXM 1 -> APIC 0x0032 -> Node 1
[    0.008833] SRAT: PXM 0 -> APIC 0x0014 -> Node 0
[    0.008833] SRAT: PXM 1 -> APIC 0x0034 -> Node 1
[    0.008834] SRAT: PXM 0 -> APIC 0x0001 -> Node 0
[    0.008835] SRAT: PXM 1 -> APIC 0x0021 -> Node 1
[    0.008835] SRAT: PXM 0 -> APIC 0x0009 -> Node 0
[    0.008836] SRAT: PXM 1 -> APIC 0x0029 -> Node 1
[    0.008837] SRAT: PXM 0 -> APIC 0x0003 -> Node 0
[    0.008837] SRAT: PXM 1 -> APIC 0x0023 -> Node 1
[    0.008838] SRAT: PXM 0 -> APIC 0x0007 -> Node 0
[    0.008839] SRAT: PXM 1 -> APIC 0x0027 -> Node 1
[    0.008839] SRAT: PXM 0 -> APIC 0x0005 -> Node 0
[    0.008840] SRAT: PXM 1 -> APIC 0x0025 -> Node 1
[    0.008841] SRAT: PXM 0 -> APIC 0x0019 -> Node 0
[    0.008841] SRAT: PXM 1 -> APIC 0x0039 -> Node 1
[    0.008842] SRAT: PXM 0 -> APIC 0x0011 -> Node 0
[    0.008843] SRAT: PXM 1 -> APIC 0x0031 -> Node 1
[    0.008843] SRAT: PXM 0 -> APIC 0x0017 -> Node 0
[    0.008844] SRAT: PXM 1 -> APIC 0x0037 -> Node 1
[    0.008845] SRAT: PXM 0 -> APIC 0x0013 -> Node 0
[    0.008845] SRAT: PXM 1 -> APIC 0x0033 -> Node 1
[    0.008846] SRAT: PXM 0 -> APIC 0x0015 -> Node 0
[    0.008847] SRAT: PXM 1 -> APIC 0x0035 -> Node 1
[    0.008854] ACPI: SRAT: Node 0 PXM 0 [mem 0x00000000-0x7fffffff]
[    0.008855] ACPI: SRAT: Node 0 PXM 0 [mem 0x100000000-0x207fffffff]
[    0.008856] ACPI: SRAT: Node 1 PXM 1 [mem 0x2080000000-0x407fffffff]
[    0.008862] NUMA: Node 0 [mem 0x00000000-0x7fffffff] + [mem 0x100000000-0x207fffffff] -> [mem 0x00000000-0x207fffffff]
[    0.008865] NODE_DATA(0) allocated [mem 0x207fffc000-0x207fffffff]
[    0.008869] NODE_DATA(1) allocated [mem 0x407fff9000-0x407fffcfff]
[    0.008880] Reserving 256MB of memory at 624MB for crashkernel (System RAM: 261600MB)
[    0.009066] Zone ranges:
[    0.009067]   DMA      [mem 0x0000000000001000-0x0000000000ffffff]
[    0.009068]   DMA32    [mem 0x0000000001000000-0x00000000ffffffff]
[    0.009069]   Normal   [mem 0x0000000100000000-0x000000407fffffff]
[    0.009070] Movable zone start for each node
[    0.009071] Early memory node ranges
[    0.009072]   node   0: [mem 0x0000000000001000-0x000000000009ffff]
[    0.009073]   node   0: [mem 0x0000000000100000-0x00000000474a3fff]
[    0.009074]   node   0: [mem 0x000000004758f000-0x000000004761bfff]
[    0.009075]   node   0: [mem 0x00000000476ee000-0x000000005e2fefff]
[    0.009075]   node   0: [mem 0x000000006ffff000-0x000000006fffffff]
[    0.009076]   node   0: [mem 0x0000000100000000-0x000000207fffffff]
[    0.009085]   node   1: [mem 0x0000002080000000-0x000000407fffffff]
[    0.009434] Zeroed struct page in unavailable ranges: 40734 pages
[    0.009435] Initmem setup node 0 [mem 0x0000000000001000-0x000000207fffffff]
[    0.494873] Initmem setup node 1 [mem 0x0000002080000000-0x000000407fffffff]
[    1.026160] ACPI: PM-Timer IO Port: 0x508
[    1.026173] ACPI: x2apic entry ignored
[    1.026173] ACPI: x2apic entry ignored
[    1.026174] ACPI: x2apic entry ignored
[    1.026174] ACPI: x2apic entry ignored
[    1.026175] ACPI: x2apic entry ignored
[    1.026175] ACPI: x2apic entry ignored
[    1.026176] ACPI: x2apic entry ignored
[    1.026176] ACPI: x2apic entry ignored
[    1.026177] ACPI: x2apic entry ignored
[    1.026177] ACPI: x2apic entry ignored
[    1.026178] ACPI: x2apic entry ignored
[    1.026178] ACPI: x2apic entry ignored
[    1.026179] ACPI: x2apic entry ignored
[    1.026179] ACPI: x2apic entry ignored
[    1.026179] ACPI: x2apic entry ignored
[    1.026180] ACPI: x2apic entry ignored
[    1.026180] ACPI: x2apic entry ignored
[    1.026181] ACPI: x2apic entry ignored
[    1.026181] ACPI: x2apic entry ignored
[    1.026182] ACPI: x2apic entry ignored
[    1.026182] ACPI: x2apic entry ignored
[    1.026183] ACPI: x2apic entry ignored
[    1.026183] ACPI: x2apic entry ignored
[    1.026184] ACPI: x2apic entry ignored
[    1.026184] ACPI: x2apic entry ignored
[    1.026185] ACPI: x2apic entry ignored
[    1.026185] ACPI: x2apic entry ignored
[    1.026186] ACPI: x2apic entry ignored
[    1.026186] ACPI: x2apic entry ignored
[    1.026187] ACPI: x2apic entry ignored
[    1.026187] ACPI: x2apic entry ignored
[    1.026188] ACPI: x2apic entry ignored
[    1.026188] ACPI: x2apic entry ignored
[    1.026188] ACPI: x2apic entry ignored
[    1.026189] ACPI: x2apic entry ignored
[    1.026189] ACPI: x2apic entry ignored
[    1.026190] ACPI: x2apic entry ignored
[    1.026190] ACPI: x2apic entry ignored
[    1.026191] ACPI: x2apic entry ignored
[    1.026191] ACPI: x2apic entry ignored
[    1.026192] ACPI: x2apic entry ignored
[    1.026192] ACPI: x2apic entry ignored
[    1.026193] ACPI: x2apic entry ignored
[    1.026193] ACPI: x2apic entry ignored
[    1.026194] ACPI: x2apic entry ignored
[    1.026194] ACPI: x2apic entry ignored
[    1.026195] ACPI: x2apic entry ignored
[    1.026195] ACPI: x2apic entry ignored
[    1.026196] ACPI: x2apic entry ignored
[    1.026196] ACPI: x2apic entry ignored
[    1.026197] ACPI: x2apic entry ignored
[    1.026197] ACPI: x2apic entry ignored
[    1.026198] ACPI: x2apic entry ignored
[    1.026198] ACPI: x2apic entry ignored
[    1.026198] ACPI: x2apic entry ignored
[    1.026199] ACPI: x2apic entry ignored
[    1.026199] ACPI: x2apic entry ignored
[    1.026200] ACPI: x2apic entry ignored
[    1.026200] ACPI: x2apic entry ignored
[    1.026201] ACPI: x2apic entry ignored
[    1.026201] ACPI: x2apic entry ignored
[    1.026202] ACPI: x2apic entry ignored
[    1.026202] ACPI: x2apic entry ignored
[    1.026203] ACPI: x2apic entry ignored
[    1.026203] ACPI: x2apic entry ignored
[    1.026204] ACPI: x2apic entry ignored
[    1.026204] ACPI: x2apic entry ignored
[    1.026205] ACPI: x2apic entry ignored
[    1.026205] ACPI: x2apic entry ignored
[    1.026206] ACPI: x2apic entry ignored
[    1.026206] ACPI: x2apic entry ignored
[    1.026207] ACPI: x2apic entry ignored
[    1.026207] ACPI: x2apic entry ignored
[    1.026207] ACPI: x2apic entry ignored
[    1.026208] ACPI: x2apic entry ignored
[    1.026208] ACPI: x2apic entry ignored
[    1.026209] ACPI: x2apic entry ignored
[    1.026209] ACPI: x2apic entry ignored
[    1.026210] ACPI: x2apic entry ignored
[    1.026210] ACPI: x2apic entry ignored
[    1.026211] ACPI: x2apic entry ignored
[    1.026211] ACPI: x2apic entry ignored
[    1.026212] ACPI: x2apic entry ignored
[    1.026212] ACPI: x2apic entry ignored
[    1.026213] ACPI: x2apic entry ignored
[    1.026213] ACPI: x2apic entry ignored
[    1.026214] ACPI: x2apic entry ignored
[    1.026214] ACPI: x2apic entry ignored
[    1.026215] ACPI: x2apic entry ignored
[    1.026215] ACPI: x2apic entry ignored
[    1.026216] ACPI: x2apic entry ignored
[    1.026216] ACPI: x2apic entry ignored
[    1.026217] ACPI: x2apic entry ignored
[    1.026217] ACPI: x2apic entry ignored
[    1.026217] ACPI: x2apic entry ignored
[    1.026218] ACPI: x2apic entry ignored
[    1.026218] ACPI: x2apic entry ignored
[    1.026219] ACPI: x2apic entry ignored
[    1.026219] ACPI: x2apic entry ignored
[    1.026220] ACPI: x2apic entry ignored
[    1.026220] ACPI: x2apic entry ignored
[    1.026221] ACPI: x2apic entry ignored
[    1.026221] ACPI: x2apic entry ignored
[    1.026222] ACPI: x2apic entry ignored
[    1.026222] ACPI: x2apic entry ignored
[    1.026223] ACPI: x2apic entry ignored
[    1.026223] ACPI: x2apic entry ignored
[    1.026224] ACPI: x2apic entry ignored
[    1.026224] ACPI: x2apic entry ignored
[    1.026225] ACPI: x2apic entry ignored
[    1.026225] ACPI: x2apic entry ignored
[    1.026226] ACPI: x2apic entry ignored
[    1.026226] ACPI: x2apic entry ignored
[    1.026226] ACPI: x2apic entry ignored
[    1.026227] ACPI: x2apic entry ignored
[    1.026227] ACPI: x2apic entry ignored
[    1.026228] ACPI: x2apic entry ignored
[    1.026228] ACPI: x2apic entry ignored
[    1.026229] ACPI: x2apic entry ignored
[    1.026229] ACPI: x2apic entry ignored
[    1.026230] ACPI: x2apic entry ignored
[    1.026230] ACPI: x2apic entry ignored
[    1.026231] ACPI: x2apic entry ignored
[    1.026231] ACPI: x2apic entry ignored
[    1.026232] ACPI: x2apic entry ignored
[    1.026232] ACPI: x2apic entry ignored
[    1.026233] ACPI: x2apic entry ignored
[    1.026233] ACPI: x2apic entry ignored
[    1.026234] ACPI: x2apic entry ignored
[    1.026234] ACPI: x2apic entry ignored
[    1.026235] ACPI: x2apic entry ignored
[    1.026235] ACPI: x2apic entry ignored
[    1.026236] ACPI: x2apic entry ignored
[    1.026236] ACPI: x2apic entry ignored
[    1.026236] ACPI: x2apic entry ignored
[    1.026237] ACPI: x2apic entry ignored
[    1.026237] ACPI: x2apic entry ignored
[    1.026238] ACPI: x2apic entry ignored
[    1.026238] ACPI: x2apic entry ignored
[    1.026239] ACPI: x2apic entry ignored
[    1.026239] ACPI: x2apic entry ignored
[    1.026240] ACPI: x2apic entry ignored
[    1.026240] ACPI: x2apic entry ignored
[    1.026241] ACPI: x2apic entry ignored
[    1.026241] ACPI: x2apic entry ignored
[    1.026242] ACPI: x2apic entry ignored
[    1.026242] ACPI: x2apic entry ignored
[    1.026243] ACPI: x2apic entry ignored
[    1.026243] ACPI: x2apic entry ignored
[    1.026244] ACPI: x2apic entry ignored
[    1.026244] ACPI: x2apic entry ignored
[    1.026245] ACPI: x2apic entry ignored
[    1.026245] ACPI: x2apic entry ignored
[    1.026246] ACPI: x2apic entry ignored
[    1.026246] ACPI: x2apic entry ignored
[    1.026247] ACPI: x2apic entry ignored
[    1.026247] ACPI: x2apic entry ignored
[    1.026247] ACPI: x2apic entry ignored
[    1.026248] ACPI: x2apic entry ignored
[    1.026248] ACPI: x2apic entry ignored
[    1.026249] ACPI: x2apic entry ignored
[    1.026249] ACPI: x2apic entry ignored
[    1.026250] ACPI: x2apic entry ignored
[    1.026250] ACPI: x2apic entry ignored
[    1.026251] ACPI: x2apic entry ignored
[    1.026251] ACPI: x2apic entry ignored
[    1.026252] ACPI: x2apic entry ignored
[    1.026252] ACPI: x2apic entry ignored
[    1.026253] ACPI: x2apic entry ignored
[    1.026253] ACPI: x2apic entry ignored
[    1.026254] ACPI: x2apic entry ignored
[    1.026254] ACPI: x2apic entry ignored
[    1.026255] ACPI: x2apic entry ignored
[    1.026255] ACPI: x2apic entry ignored
[    1.026256] ACPI: x2apic entry ignored
[    1.026256] ACPI: x2apic entry ignored
[    1.026257] ACPI: x2apic entry ignored
[    1.026257] ACPI: x2apic entry ignored
[    1.026257] ACPI: x2apic entry ignored
[    1.026258] ACPI: x2apic entry ignored
[    1.026258] ACPI: x2apic entry ignored
[    1.026259] ACPI: x2apic entry ignored
[    1.026259] ACPI: x2apic entry ignored
[    1.026260] ACPI: x2apic entry ignored
[    1.026260] ACPI: x2apic entry ignored
[    1.026261] ACPI: x2apic entry ignored
[    1.026261] ACPI: x2apic entry ignored
[    1.026262] ACPI: x2apic entry ignored
[    1.026262] ACPI: x2apic entry ignored
[    1.026263] ACPI: x2apic entry ignored
[    1.026263] ACPI: x2apic entry ignored
[    1.026264] ACPI: x2apic entry ignored
[    1.026264] ACPI: x2apic entry ignored
[    1.026265] ACPI: x2apic entry ignored
[    1.026265] ACPI: x2apic entry ignored
[    1.026266] ACPI: x2apic entry ignored
[    1.026266] ACPI: x2apic entry ignored
[    1.026266] ACPI: x2apic entry ignored
[    1.026267] ACPI: x2apic entry ignored
[    1.026267] ACPI: x2apic entry ignored
[    1.026268] ACPI: x2apic entry ignored
[    1.026268] ACPI: x2apic entry ignored
[    1.026269] ACPI: x2apic entry ignored
[    1.026269] ACPI: x2apic entry ignored
[    1.026270] ACPI: x2apic entry ignored
[    1.026270] ACPI: x2apic entry ignored
[    1.026271] ACPI: x2apic entry ignored
[    1.026271] ACPI: x2apic entry ignored
[    1.026272] ACPI: x2apic entry ignored
[    1.026272] ACPI: x2apic entry ignored
[    1.026273] ACPI: x2apic entry ignored
[    1.026273] ACPI: x2apic entry ignored
[    1.026274] ACPI: x2apic entry ignored
[    1.026274] ACPI: x2apic entry ignored
[    1.026275] ACPI: x2apic entry ignored
[    1.026275] ACPI: x2apic entry ignored
[    1.026276] ACPI: x2apic entry ignored
[    1.026276] ACPI: x2apic entry ignored
[    1.026277] ACPI: x2apic entry ignored
[    1.026277] ACPI: x2apic entry ignored
[    1.026278] ACPI: x2apic entry ignored
[    1.026278] ACPI: x2apic entry ignored
[    1.026278] ACPI: x2apic entry ignored
[    1.026279] ACPI: x2apic entry ignored
[    1.026283] ACPI: X2APIC_NMI (uid[0xffffffff] high level lint[0x1])
[    1.026285] ACPI: LAPIC_NMI (acpi_id[0xff] high level lint[0x1])
[    1.026303] IOAPIC[0]: apic_id 8, version 32, address 0xfec00000, GSI 0-23
[    1.026307] IOAPIC[1]: apic_id 9, version 32, address 0xfec01000, GSI 24-31
[    1.026311] IOAPIC[2]: apic_id 10, version 32, address 0xfec08000, GSI 32-39
[    1.026315] IOAPIC[3]: apic_id 11, version 32, address 0xfec10000, GSI 40-47
[    1.026319] IOAPIC[4]: apic_id 12, version 32, address 0xfec18000, GSI 48-55
[    1.026323] IOAPIC[5]: apic_id 15, version 32, address 0xfec20000, GSI 72-79
[    1.026328] IOAPIC[6]: apic_id 16, version 32, address 0xfec28000, GSI 80-87
[    1.026332] IOAPIC[7]: apic_id 17, version 32, address 0xfec30000, GSI 88-95
[    1.026337] IOAPIC[8]: apic_id 18, version 32, address 0xfec38000, GSI 96-103
[    1.026340] ACPI: INT_SRC_OVR (bus 0 bus_irq 0 global_irq 2 dfl dfl)
[    1.026342] ACPI: INT_SRC_OVR (bus 0 bus_irq 9 global_irq 9 high level)
[    1.026348] Using ACPI (MADT) for SMP configuration information
[    1.026350] ACPI: HPET id: 0x8086a701 base: 0xfed00000
[    1.026353] smpboot: Allowing 40 CPUs, 0 hotplug CPUs
[    1.026370] [mem 0x90000000-0xfdffffff] available for PCI devices
[    1.026374] clocksource: refined-jiffies: mask: 0xffffffff max_cycles: 0xffffffff, max_idle_ns: 1910969940391419 ns
[    1.031515] setup_percpu: NR_CPUS:256 nr_cpumask_bits:256 nr_cpu_ids:40 nr_node_ids:2
[    1.034956] percpu: Embedded 54 pages/cpu s180504 r8192 d32488 u262144
[    1.034999] Built 2 zonelists, mobility grouping on.  Total pages: 65922237
[    1.035000] Policy zone: Normal
[    1.035001] Kernel command line: BOOT_IMAGE=/boot/bzImage-5.6.0-rc2.mx64.322 root=LABEL=root ro crashkernel=256M console=ttyS1,115200n8 console=tty0 init=/bin/systemd audit=0 random.trust_cpu=on
[    1.035112] audit: disabled (until reboot)
[    1.035136] printk: log_buf_len individual max cpu contribution: 4096 bytes
[    1.035137] printk: log_buf_len total cpu_extra contributions: 159744 bytes
[    1.035138] printk: log_buf_len min size: 131072 bytes
[    1.035302] printk: log_buf_len: 524288 bytes
[    1.035303] printk: early log buf free: 106124(80%)
[    1.035646] mem auto-init: stack:off, heap alloc:off, heap free:off
[    1.632683] Memory: 263209212K/267879304K available (14340K kernel code, 1625K rwdata, 3656K rodata, 1540K init, 972K bss, 4670092K reserved, 0K cma-reserved)
[    1.633469] ftrace: allocating 41240 entries in 162 pages
[    1.648215] ftrace: allocated 162 pages with 3 groups
[    1.648467] rcu: Hierarchical RCU implementation.
[    1.648467] rcu:     RCU event tracing is enabled.
[    1.648468] rcu:     RCU restricting CPUs from NR_CPUS=256 to nr_cpu_ids=40.
[    1.648470] rcu: RCU calculated value of scheduler-enlistment delay is 100 jiffies.
[    1.648470] rcu: Adjusting geometry for rcu_fanout_leaf=16, nr_cpu_ids=40
[    1.651303] NR_IRQS: 16640, nr_irqs: 2104, preallocated irqs: 16
[    1.651609] random: crng done (trusting CPU's manufacturer)
[    1.652452] Console: colour dummy device 80x25
[    1.652883] printk: console [tty0] enabled
[    3.669892] printk: console [ttyS1] enabled
[    3.674156] ACPI: Core revision 20200110
[    3.681230] clocksource: hpet: mask: 0xffffffff max_cycles: 0xffffffff, max_idle_ns: 79635855245 ns
[    3.690285] APIC: Switch to symmetric I/O mode setup
[    3.695246] Switched APIC routing to physical flat.
[    3.700124] ------------[ cut here ]------------
[    3.704726] kernel BUG at arch/x86/kernel/apic/apic.c:1629!
[    3.710300] invalid opcode: 0000 [#1] SMP NOPTI
[    3.714815] CPU: 0 PID: 0 Comm: swapper/0 Not tainted 5.6.0-rc2.mx64.322 #1
[    3.721756] Hardware name: Dell Inc. PowerEdge T640/04WYPY, BIOS 2.4.8 11/27/2019
[    3.729222] RIP: 0010:setup_local_APIC+0x32e/0x390
[    3.734001] Code: 78 57 2e 01 be 00 07 01 00 bf 50 03 00 00 48 8b 40 10 e8 35 85 db 00 eb a9 be 00 04 01 00 bf 60 03 00 00 e8 24 85 db 00 eb bb <0f> 0b e8 5b 3a 00 00 e9 11 ff ff ff be 00 04 00 00 bf 60 03 00 00
[    3.752700] RSP: 0000:ffffffff82403e90 EFLAGS: 00010246
[    3.757914] RAX: 0000000000000000 RBX: 00000000000000a2 RCX: ffffffff82456088
[    3.765029] RDX: 0000000000000000 RSI: 00000000fffffeff RDI: 0000000000000020
[    3.772144] RBP: 0000000000000000 R08: 00000000000001cc R09: 0720072007200720
[    3.779260] R10: ffffffff8258d940 R11: 0720072007200720 R12: ffff88c07ffeee80
[    3.786374] R13: 0000000000000000 R14: 00000000000000a2 R15: 000000004647bcbc
[    3.793492] FS:  0000000000000000(0000) GS:ffff889fffe00000(0000) knlGS:0000000000000000
[    3.801557] CS:  0010 DS: 0000 ES: 0000 CR0: 0000000080050033
[    3.807288] CR2: ffff88c07ffff000 CR3: 000000000240a001 CR4: 00000000000606b0
[    3.814405] DR0: 0000000000000000 DR1: 0000000000000000 DR2: 0000000000000000
[    3.821520] DR3: 0000000000000000 DR6: 00000000fffe0ff0 DR7: 0000000000000400
[    3.828633] Call Trace:
[    3.831077]  apic_intr_mode_init+0xd6/0xef
[    3.835165]  x86_late_time_init+0x20/0x25
[    3.839167]  start_kernel+0x66b/0x71f
[    3.842825]  secondary_startup_64+0xa4/0xb0
[    3.846998] Modules linked in:
[    3.850077] ---[ end trace a223188007b81154 ]---
[    3.854697] RIP: 0010:setup_local_APIC+0x32e/0x390
[    3.859486] Code: 78 57 2e 01 be 00 07 01 00 bf 50 03 00 00 48 8b 40 10 e8 35 85 db 00 eb a9 be 00 04 01 00 bf 60 03 00 00 e8 24 85 db 00 eb bb <0f> 0b e8 5b 3a 00 00 e9 11 ff ff ff be 00 04 00 00 bf 60 03 00 00
[    3.878196] RSP: 0000:ffffffff82403e90 EFLAGS: 00010246
[    3.883418] RAX: 0000000000000000 RBX: 00000000000000a2 RCX: ffffffff82456088
[    3.890540] RDX: 0000000000000000 RSI: 00000000fffffeff RDI: 0000000000000020
[    3.897666] RBP: 0000000000000000 R08: 00000000000001cc R09: 0720072007200720
[    3.904790] R10: ffffffff8258d940 R11: 0720072007200720 R12: ffff88c07ffeee80
[    3.911913] R13: 0000000000000000 R14: 00000000000000a2 R15: 000000004647bcbc
[    3.919037] FS:  0000000000000000(0000) GS:ffff889fffe00000(0000) knlGS:0000000000000000
[    3.927113] CS:  0010 DS: 0000 ES: 0000 CR0: 0000000080050033
[    3.932854] CR2: ffff88c07ffff000 CR3: 000000000240a001 CR4: 00000000000606b0
[    3.939977] DR0: 0000000000000000 DR1: 0000000000000000 DR2: 0000000000000000
[    3.947100] DR3: 0000000000000000 DR6: 00000000fffe0ff0 DR7: 0000000000000400
[    3.954225] Kernel panic - not syncing: Attempted to kill the idle task!
[    3.960923] ---[ end Kernel panic - not syncing: Attempted to kill the idle task! ]---

[-- Attachment #2: S/MIME Cryptographic Signature --]
[-- Type: application/pkcs7-signature, Size: 5174 bytes --]

^ permalink raw reply	[flat|nested] 7+ messages in thread

* Re: kernel BUG at arch/x86/kernel/apic/apic.c with Dell server with x2APIC enabled and unset X2APIC
  2020-02-21 16:27 ` Thomas Gleixner
@ 2020-02-24 12:59   ` Paul Menzel
  0 siblings, 0 replies; 7+ messages in thread
From: Paul Menzel @ 2020-02-24 12:59 UTC (permalink / raw)
  To: Thomas Gleixner, Ingo Molnar, Borislav Petkov; +Cc: x86, LKML, it+linux-x86

[-- Attachment #1: Type: text/plain, Size: 991 bytes --]

Dear Thomas,


On 2020-02-21 17:27, Thomas Gleixner wrote:

> Paul Menzel writes:
>>
>> On the Dell PowerEdge T640/04WYPY, BIOS 2.4.8 11/27/2019, Linux 5.4.14 (and 4.19.57) with
>> unset `IRQ_REMAP` and `X86_X2APIC` crashes on start-up, when x2APIC is enabled in the
>> firmware.
> 
>>     [    3.883893] Switched APIC routing to physical flat.
>>     [    3.888904] ------------[ cut here ]------------
>>     [    3.893641] kernel BUG at arch/x86/kernel/apic/apic.c:1616!
> 
> So the APIC is not registered.
>>
>> `noapic` and `acpi=off` separately did not work, but `noapic acpi=off` hit the other
>> panic.
> 
> I have no idea what you are talking about.
> 
> Which command line options are set to reproduce the above?

Sorry, please ignore my debugging attempts. It fails without any of
these.

> Also please test the latest stable kernels not some random ones.

Please see my reply to Borislav with the logs of Linux 5.6-rc2.


Kind regards,

Paul


[-- Attachment #2: S/MIME Cryptographic Signature --]
[-- Type: application/pkcs7-signature, Size: 5174 bytes --]

^ permalink raw reply	[flat|nested] 7+ messages in thread

* [tip: x86/apic] x86/apic: Handle no CONFIG_X86_X2APIC on systems with x2APIC enabled by BIOS
  2020-02-21 14:37 kernel BUG at arch/x86/kernel/apic/apic.c with Dell server with x2APIC enabled and unset X2APIC Paul Menzel
  2020-02-21 15:57 ` Borislav Petkov
  2020-02-21 16:27 ` Thomas Gleixner
@ 2022-12-02 13:35 ` tip-bot2 for Mateusz Jończyk
  2 siblings, 0 replies; 7+ messages in thread
From: tip-bot2 for Mateusz Jończyk @ 2022-12-02 13:35 UTC (permalink / raw)
  To: linux-tip-commits
  Cc: Paul Menzel, Robert Elliott (Servers),
	mat.jonczyk, Thomas Gleixner, x86, linux-kernel

The following commit has been merged into the x86/apic branch of tip:

Commit-ID:     e3998434da4f5b1f57f8d6a8a9f8502ee3723bae
Gitweb:        https://git.kernel.org/tip/e3998434da4f5b1f57f8d6a8a9f8502ee3723bae
Author:        Mateusz Jończyk <mat.jonczyk@o2.pl>
AuthorDate:    Tue, 29 Nov 2022 22:50:08 +01:00
Committer:     Thomas Gleixner <tglx@linutronix.de>
CommitterDate: Fri, 02 Dec 2022 14:28:52 +01:00

x86/apic: Handle no CONFIG_X86_X2APIC on systems with x2APIC enabled by BIOS

A kernel that was compiled without CONFIG_X86_X2APIC was unable to boot on
platforms that have x2APIC already enabled in the BIOS before starting the
kernel.

The kernel was supposed to panic with an approprite error message in
validate_x2apic() due to the missing X2APIC support.

However, validate_x2apic() was run too late in the boot cycle, and the
kernel tried to initialize the APIC nonetheless. This resulted in an
earlier panic in setup_local_APIC() because the APIC was not registered.

In my experiments, a panic message in setup_local_APIC() was not visible
in the graphical console, which resulted in a hang with no indication
what has gone wrong.

Instead of calling panic(), disable the APIC, which results in a somewhat
working system with the PIC only (and no SMP). This way the user is able to
diagnose the problem more easily.

Disabling X2APIC mode is not an option because it's impossible on systems
with locked x2APIC.

The proper place to disable the APIC in this case is in check_x2apic(),
which is called early from setup_arch(). Doing this in
__apic_intr_mode_select() is too late.

Make check_x2apic() unconditionally available and remove the empty stub.

Reported-by: Paul Menzel <pmenzel@molgen.mpg.de>
Reported-by: Robert Elliott (Servers) <elliott@hpe.com>
Signed-off-by: Mateusz Jończyk <mat.jonczyk@o2.pl>
Signed-off-by: Thomas Gleixner <tglx@linutronix.de>
Link: https://lore.kernel.org/lkml/d573ba1c-0dc4-3016-712a-cc23a8a33d42@molgen.mpg.de
Link: https://lore.kernel.org/lkml/20220911084711.13694-3-mat.jonczyk@o2.pl
Link: https://lore.kernel.org/all/20221129215008.7247-1-mat.jonczyk@o2.pl
---
 arch/x86/Kconfig            |  4 ++--
 arch/x86/include/asm/apic.h |  3 +--
 arch/x86/kernel/apic/apic.c | 13 ++++++++-----
 3 files changed, 11 insertions(+), 9 deletions(-)

diff --git a/arch/x86/Kconfig b/arch/x86/Kconfig
index 67745ce..b2c0fce 100644
--- a/arch/x86/Kconfig
+++ b/arch/x86/Kconfig
@@ -462,8 +462,8 @@ config X86_X2APIC
 
 	  Some Intel systems circa 2022 and later are locked into x2APIC mode
 	  and can not fall back to the legacy APIC modes if SGX or TDX are
-	  enabled in the BIOS.  They will be unable to boot without enabling
-	  this option.
+	  enabled in the BIOS. They will boot with very reduced functionality
+	  without enabling this option.
 
 	  If you don't know what to do here, say N.
 
diff --git a/arch/x86/include/asm/apic.h b/arch/x86/include/asm/apic.h
index 3415321..3216da7 100644
--- a/arch/x86/include/asm/apic.h
+++ b/arch/x86/include/asm/apic.h
@@ -249,7 +249,6 @@ static inline u64 native_x2apic_icr_read(void)
 extern int x2apic_mode;
 extern int x2apic_phys;
 extern void __init x2apic_set_max_apicid(u32 apicid);
-extern void __init check_x2apic(void);
 extern void x2apic_setup(void);
 static inline int x2apic_enabled(void)
 {
@@ -258,13 +257,13 @@ static inline int x2apic_enabled(void)
 
 #define x2apic_supported()	(boot_cpu_has(X86_FEATURE_X2APIC))
 #else /* !CONFIG_X86_X2APIC */
-static inline void check_x2apic(void) { }
 static inline void x2apic_setup(void) { }
 static inline int x2apic_enabled(void) { return 0; }
 
 #define x2apic_mode		(0)
 #define	x2apic_supported()	(0)
 #endif /* !CONFIG_X86_X2APIC */
+extern void __init check_x2apic(void);
 
 struct irq_data;
 
diff --git a/arch/x86/kernel/apic/apic.c b/arch/x86/kernel/apic/apic.c
index c6876d3..20d9a60 100644
--- a/arch/x86/kernel/apic/apic.c
+++ b/arch/x86/kernel/apic/apic.c
@@ -1931,16 +1931,19 @@ void __init check_x2apic(void)
 	}
 }
 #else /* CONFIG_X86_X2APIC */
-static int __init validate_x2apic(void)
+void __init check_x2apic(void)
 {
 	if (!apic_is_x2apic_enabled())
-		return 0;
+		return;
 	/*
 	 * Checkme: Can we simply turn off x2apic here instead of panic?
 	 */
-	panic("BIOS has enabled x2apic but kernel doesn't support x2apic, please disable x2apic in BIOS.\n");
+	pr_err("Kernel does not support x2APIC, please recompile with CONFIG_X86_X2APIC.\n");
+	pr_err("Disabling APIC, expect reduced performance and functionality.\n");
+
+	disable_apic = 1;
+	setup_clear_cpu_cap(X86_FEATURE_APIC);
 }
-early_initcall(validate_x2apic);
 
 static inline void try_to_enable_x2apic(int remap_mode) { }
 static inline void __x2apic_enable(void) { }

^ permalink raw reply related	[flat|nested] 7+ messages in thread

end of thread, other threads:[~2022-12-02 13:36 UTC | newest]

Thread overview: 7+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -1931,16 +1931,19 @@ void __init check_x2apic(void)
 	/*
-	 * Checkme: Can we simply turn off x2apic here instead of panic?
+	 * Checkme: Can we simply turn off x2APIC here instead of disabling the APIC?
 	 */
2020-02-21 14:37 kernel BUG at arch/x86/kernel/apic/apic.c with Dell server with x2APIC enabled and unset X2APIC Paul Menzel
2020-02-21 15:57 ` Borislav Petkov
2020-02-21 16:15   ` Paul Menzel
2020-02-21 16:27     ` Paul Menzel
2020-02-21 16:27 ` Thomas Gleixner
2020-02-24 12:59   ` Paul Menzel
2022-12-02 13:35 ` [tip: x86/apic] x86/apic: Handle no CONFIG_X86_X2APIC on systems with x2APIC enabled by BIOS tip-bot2 for Mateusz Jończyk

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).